
import dbus
import unittest

from tests.utils import (
    kill_process,
    setup_test_env,
    start_dbus_daemon,
)
setup_test_env()

from softwarecenter.db.dataprovider import SoftwareCenterDataProvider



class DataProviderTestCase(unittest.TestCase):

    @classmethod
    def setUpClass(cls):
        cls.proc, dbus_address = start_dbus_daemon()
        cls.bus = dbus.bus.BusConnection(dbus_address)
        bus_name = dbus.service.BusName(
            'com.ubuntu.SoftwareCenterDataProvider', cls.bus)
        # get the provider
        cls.provider = SoftwareCenterDataProvider(bus_name)

    @classmethod
    def tearDownClass(cls):
        cls.provider.stop()
        kill_process(cls.proc)

    def test_have_data_in_db(self):
        self.assertTrue(len(self.provider.db) > 100)

    # details
    def test_get_details(self):
        result = self.provider.GetAppDetails("", "gedit")
        self.assertEqual(result["component"], "main")
        self.assertEqual(result["icon"], "accessories-text-editor")
        self.assertEqual(result["name"], "gedit")
        self.assertEqual(result["pkgname"], "gedit")
        self.assertEqual(result["price"], "Free")
        self.assertEqual(result["raw_price"], "")

    # get available categories/subcategories
    def test_get_categories(self):
        result = self.provider.GetAvailableCategories()
        self.assertTrue("Internet" in result)

    def test_get_subcategories(self):
        result = self.provider.GetAvailableSubcategories("Internet")
        self.assertTrue("Chat" in result)

    # get category
    def test_get_category_internet(self):
        result = self.provider.GetItemsForCategory("Internet")
        self.assertTrue(
            ("Firefox Web Browser",  # app
             "firefox",  # pkgname
             "firefox",  # iconname
             "/usr/share/app-install/desktop/firefox:firefox.desktop",
             ) in result)

    def test_get_category_top_rated(self):
        result = self.provider.GetItemsForCategory("Top Rated")
        self.assertEqual(len(result), 100)

    def test_get_category_whats_new(self):
        result = self.provider.GetItemsForCategory(u"What\u2019s New")
        self.assertEqual(len(result), 20)

if __name__ == "__main__":
    unittest.main()
